@@ -1,30 +1,43 @@
 from typing import Union, Callable, Optional
 from typing_extensions import TypedDict
 
+from ..types import (
+    InputContext,
+    ScenarioView,
+    AgentListParams,
+    DevboxListParams,
+    ObjectListParams,
+    AgentCreateParams,
+    DevboxCreateParams,
+    ObjectCreateParams,
+    ScenarioListParams,
+    BenchmarkListParams,
+    BlueprintListParams,
+    ObjectDownloadParams,
+    ScenarioUpdateParams,
+    BenchmarkCreateParams,
+    BenchmarkUpdateParams,
+    BlueprintCreateParams,
+    DevboxUploadFileParams,
+    NetworkPolicyListParams,
+    DevboxCreateTunnelParams,
+    DevboxDownloadFileParams,
+    DevboxRemoveTunnelParams,
+    DevboxSnapshotDiskParams,
+    NetworkPolicyCreateParams,
+    NetworkPolicyUpdateParams,
+    DevboxReadFileContentsParams,
+    DevboxWriteFileContentsParams,
+    BenchmarkRunListScenarioRunsParams,
+)
 from .._types import Body, Query, Headers, Timeout, NotGiven
 from ..lib.polling import PollingConfig
 from ..types.devboxes import DiskSnapshotListParams, DiskSnapshotUpdateParams
 from ..types.scenarios import ScorerListParams, ScorerCreateParams, ScorerUpdateParams, ScorerValidateParams
-from ..types.agent_list_params import AgentListParams
-from ..types.devbox_list_params import DevboxListParams
-from ..types.object_list_params import ObjectListParams
-from ..types.agent_create_params import AgentCreateParams
-from ..types.devbox_create_params import DevboxCreateParams, DevboxBaseCreateParams
-from ..types.object_create_params import ObjectCreateParams
-from ..types.scenario_list_params import ScenarioListParams
-from ..types.blueprint_list_params import BlueprintListParams
-from ..types.object_download_params import ObjectDownloadParams
-from ..types.scenario_update_params import ScenarioUpdateParams
-from ..types.blueprint_create_params import BlueprintCreateParams
-from ..types.devbox_upload_file_params import DevboxUploadFileParams
+from ..types.devbox_create_params import DevboxBaseCreateParams
 from ..types.scenario_start_run_params import ScenarioStartRunBaseParams
-from ..types.devbox_create_tunnel_params import DevboxCreateTunnelParams
-from ..types.devbox_download_file_params import DevboxDownloadFileParams
+from ..types.benchmark_start_run_params import BenchmarkSelfStartRunParams
 from ..types.devbox_execute_async_params import DevboxNiceExecuteAsyncParams
-from ..types.devbox_remove_tunnel_params import DevboxRemoveTunnelParams
-from ..types.devbox_snapshot_disk_params import DevboxSnapshotDiskParams
-from ..types.devbox_read_file_contents_params import DevboxReadFileContentsParams
-from ..types.devbox_write_file_contents_params import DevboxWriteFileContentsParams
 
 LogCallback = Callable[[str], None]
 
@@ -64,7 +77,7 @@ class PollingRequestOptions(BaseRequestOptions, total=False):
     """Configuration for polling behavior"""
 
 
-class LongPollingRequestOptions(LongRequestOptions, PollingRequestOptions):
+class LongPollingRequestOptions(LongRequestOptions, PollingRequestOptions):  # type: ignore[misc]
     pass
 
 
@@ -186,3 +199,61 @@ class SDKScenarioRunAsyncParams(ScenarioStartRunBaseParams, LongRequestOptions):
 
 class SDKScenarioRunParams(ScenarioStartRunBaseParams, LongPollingRequestOptions):
     pass
+
+
+class InputContextPreview(InputContext):
+    problem_statement: Optional[str] = None  # type: ignore[assignment]
+    """The problem statement for the Scenario."""
+
+
+class ScenarioPreview(ScenarioView):
+    """Preview of scenario configuration with all fields optional."""
+
+    id: Optional[str] = None  # type: ignore[assignment]
+    """The ID of the Scenario."""
+
+    input_context: InputContextPreview  # type: ignore[assignment]
+    """The input context for the Scenario."""
+
+
+class SDKBenchmarkCreateParams(BenchmarkCreateParams, LongRequestOptions):
+    pass
+
+
+class SDKBenchmarkListParams(BenchmarkListParams, BaseRequestOptions):
+    pass
+
+
+class SDKBenchmarkUpdateParams(BenchmarkUpdateParams, LongRequestOptions):
+    pass
+
+
+class SDKBenchmarkStartRunParams(BenchmarkSelfStartRunParams, LongRequestOptions):
+    pass
+
+
+class SDKBenchmarkListRunsParams(BaseRequestOptions, total=False):
+    limit: int
+    """The limit of items to return. Default is 20. Max is 5000."""
+
+    name: str
+    """Filter by name"""
+
+    starting_after: str
+    """Load the next page of data starting after the item with the given ID."""
+
+
+class SDKBenchmarkRunListScenarioRunsParams(BenchmarkRunListScenarioRunsParams, BaseRequestOptions):
+    pass
+
+
+class SDKNetworkPolicyCreateParams(NetworkPolicyCreateParams, LongRequestOptions):
+    pass
+
+
+class SDKNetworkPolicyListParams(NetworkPolicyListParams, BaseRequestOptions):
+    pass
+
+
+class SDKNetworkPolicyUpdateParams(NetworkPolicyUpdateParams, LongRequestOptions):
+    pass
