@@ -21,9 +21,13 @@ from ._types import (
     SDKObjectCreateParams,
     SDKScenarioListParams,
     SDKScorerCreateParams,
+    SDKBenchmarkListParams,
     SDKBlueprintListParams,
+    SDKBenchmarkCreateParams,
     SDKBlueprintCreateParams,
     SDKDiskSnapshotListParams,
+    SDKNetworkPolicyListParams,
+    SDKNetworkPolicyCreateParams,
     SDKDevboxCreateFromImageParams,
 )
 from .._types import Timeout, NotGiven, not_given
@@ -34,9 +38,12 @@ from .async_devbox import AsyncDevbox
 from .async_scorer import AsyncScorer
 from .async_scenario import AsyncScenario
 from .async_snapshot import AsyncSnapshot
+from .async_benchmark import AsyncBenchmark
 from .async_blueprint import AsyncBlueprint
 from ..lib.context_loader import TarFilter, build_directory_tar
+from .async_network_policy import AsyncNetworkPolicy
 from .async_storage_object import AsyncStorageObject
+from .async_scenario_builder import AsyncScenarioBuilder
 from ..types.object_create_params import ContentType
 from ..types.shared_params.agent_source import Git, Npm, Pip, Object
 
@@ -598,7 +605,6 @@ class AsyncAgentOps:
         self,
         *,
         package_name: str,
-        npm_version: Optional[str] = None,
         registry_url: Optional[str] = None,
         agent_setup: Optional[list[str]] = None,
         **params: Unpack[SDKAgentCreateParams],
@@ -607,8 +613,6 @@ class AsyncAgentOps:
 
         :param package_name: NPM package name
         :type package_name: str
-        :param npm_version: NPM version constraint, defaults to None
-        :type npm_version: Optional[str], optional
         :param registry_url: NPM registry URL, defaults to None
         :type registry_url: Optional[str], optional
         :param agent_setup: Setup commands to run after installation, defaults to None
@@ -624,8 +628,6 @@ class AsyncAgentOps:
             )
 
         npm_config: Npm = {"package_name": package_name}
-        if npm_version is not None:
-            npm_config["npm_version"] = npm_version
         if registry_url is not None:
             npm_config["registry_url"] = registry_url
         if agent_setup is not None:
@@ -638,7 +640,6 @@ class AsyncAgentOps:
         self,
         *,
         package_name: str,
-        pip_version: Optional[str] = None,
         registry_url: Optional[str] = None,
         agent_setup: Optional[list[str]] = None,
         **params: Unpack[SDKAgentCreateParams],
@@ -647,8 +648,6 @@ class AsyncAgentOps:
 
         :param package_name: Pip package name
         :type package_name: str
-        :param pip_version: Pip version constraint, defaults to None
-        :type pip_version: Optional[str], optional
         :param registry_url: Pip registry URL, defaults to None
         :type registry_url: Optional[str], optional
         :param agent_setup: Setup commands to run after installation, defaults to None
@@ -664,8 +663,6 @@ class AsyncAgentOps:
             )
 
         pip_config: Pip = {"package_name": package_name}
-        if pip_version is not None:
-            pip_config["pip_version"] = pip_version
         if registry_url is not None:
             pip_config["registry_url"] = registry_url
         if agent_setup is not None:
@@ -773,6 +770,16 @@ class AsyncScenarioOps:
         >>> scenario = runloop.scenario.from_id("scn-xxx")
         >>> run = await scenario.run()
         >>> scenarios = await runloop.scenario.list()
+
+    Example using builder:
+        >>> builder = (
+        ...     runloop.scenario.builder("my-scenario")
+        ...     .from_blueprint(blueprint)
+        ...     .with_problem_statement("Fix the bug")
+        ...     .add_test_command_scorer("tests", test_command="pytest")
+        ... )
+        >>> params = builder.build()
+        >>> scenario = await runloop.scenario.create(**params)  # equivalent to builder.push()
     """
 
     def __init__(self, client: AsyncRunloop) -> None:
@@ -783,6 +790,16 @@ class AsyncScenarioOps:
         """
         self._client = client
 
+    def builder(self, name: str) -> AsyncScenarioBuilder:
+        """Create a new scenario builder.
+
+        :param name: Name for the scenario
+        :type name: str
+        :return: A new AsyncScenarioBuilder instance
+        :rtype: AsyncScenarioBuilder
+        """
+        return AsyncScenarioBuilder(name, self._client)
+
     def from_id(self, scenario_id: str) -> AsyncScenario:
         """Get an AsyncScenario instance for an existing scenario ID.
 
@@ -804,6 +821,109 @@ class AsyncScenarioOps:
         return [AsyncScenario(self._client, item.id) async for item in page]
 
 
+class AsyncBenchmarkOps:
+    """Manage benchmarks (async). Access via ``runloop.benchmark``.
+
+    Example:
+        >>> runloop = AsyncRunloopSDK()
+        >>> benchmarks = await runloop.benchmark.list()
+        >>> benchmark = runloop.benchmark.from_id("bmd_xxx")
+        >>> run = await benchmark.start_run(run_name="evaluation-v1")
+    """
+
+    def __init__(self, client: AsyncRunloop) -> None:
+        """Initialize AsyncBenchmarkOps.
+
+        :param client: AsyncRunloop client instance
+        :type client: AsyncRunloop
+        """
+        self._client = client
+
+    async def create(self, **params: Unpack[SDKBenchmarkCreateParams]) -> AsyncBenchmark:
+        """Create a new benchmark.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKBenchmarkCreateParams` for available parameters
+        :return: The newly created benchmark
+        :rtype: AsyncBenchmark
+        """
+        response = await self._client.benchmarks.create(**params)
+        return AsyncBenchmark(self._client, response.id)
+
+    def from_id(self, benchmark_id: str) -> AsyncBenchmark:
+        """Get an AsyncBenchmark instance for an existing benchmark ID.
+
+        :param benchmark_id: ID of the benchmark
+        :type benchmark_id: str
+        :return: AsyncBenchmark instance for the given ID
+        :rtype: AsyncBenchmark
+        """
+        return AsyncBenchmark(self._client, benchmark_id)
+
+    async def list(self, **params: Unpack[SDKBenchmarkListParams]) -> list[AsyncBenchmark]:
+        """List all benchmarks, optionally filtered by parameters.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKBenchmarkListParams` for available parameters
+        :return: List of benchmarks
+        :rtype: list[AsyncBenchmark]
+        """
+        page = await self._client.benchmarks.list(**params)
+        return [AsyncBenchmark(self._client, item.id) for item in page.benchmarks]
+
+
+class AsyncNetworkPolicyOps:
+    """High-level async manager for creating and managing network policies.
+
+    Accessed via ``runloop.network_policy`` from :class:`AsyncRunloopSDK`, provides
+    coroutines to create, retrieve, update, delete, and list network policies.
+
+    Example:
+        >>> runloop = AsyncRunloopSDK()
+        >>> policy = await runloop.network_policy.create(
+        ...     name="my-policy",
+        ...     allowed_hostnames=["github.com", "*.npmjs.org"],
+        ... )
+        >>> policies = await runloop.network_policy.list()
+    """
+
+    def __init__(self, client: AsyncRunloop) -> None:
+        """Initialize AsyncNetworkPolicyOps.
+
+        :param client: AsyncRunloop client instance
+        :type client: AsyncRunloop
+        """
+        self._client = client
+
+    async def create(self, **params: Unpack[SDKNetworkPolicyCreateParams]) -> AsyncNetworkPolicy:
+        """Create a new network policy.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKNetworkPolicyCreateParams` for available parameters
+        :return: The newly created network policy
+        :rtype: AsyncNetworkPolicy
+        """
+        response = await self._client.network_policies.create(**params)
+        return AsyncNetworkPolicy(self._client, response.id)
+
+    def from_id(self, network_policy_id: str) -> AsyncNetworkPolicy:
+        """Get an AsyncNetworkPolicy instance for an existing network policy ID.
+
+        :param network_policy_id: ID of the network policy
+        :type network_policy_id: str
+        :return: AsyncNetworkPolicy instance for the given ID
+        :rtype: AsyncNetworkPolicy
+        """
+        return AsyncNetworkPolicy(self._client, network_policy_id)
+
+    async def list(self, **params: Unpack[SDKNetworkPolicyListParams]) -> list[AsyncNetworkPolicy]:
+        """List all network policies, optionally filtered by parameters.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKNetworkPolicyListParams` for available parameters
+        :return: List of network policies
+        :rtype: list[AsyncNetworkPolicy]
+        """
+        page = self._client.network_policies.list(**params)
+        return [AsyncNetworkPolicy(self._client, item.id) async for item in page]
+
+
 class AsyncRunloopSDK:
     """High-level asynchronous entry point for the Runloop SDK.
 
@@ -815,6 +935,8 @@ class AsyncRunloopSDK:
     :vartype api: AsyncRunloop
     :ivar agent: High-level async interface for agent management.
     :vartype agent: AsyncAgentOps
+    :ivar benchmark: High-level async interface for benchmark management
+    :vartype benchmark: AsyncBenchmarkOps
     :ivar devbox: High-level async interface for devbox management
     :vartype devbox: AsyncDevboxOps
     :ivar blueprint: High-level async interface for blueprint management
@@ -827,6 +949,8 @@ class AsyncRunloopSDK:
     :vartype snapshot: AsyncSnapshotOps
     :ivar storage_object: High-level async interface for storage object management
     :vartype storage_object: AsyncStorageObjectOps
+    :ivar network_policy: High-level async interface for network policy management
+    :vartype network_policy: AsyncNetworkPolicyOps
 
     Example:
         >>> runloop = AsyncRunloopSDK()  # Uses RUNLOOP_API_KEY env var
@@ -838,8 +962,10 @@ class AsyncRunloopSDK:
 
     api: AsyncRunloop
     agent: AsyncAgentOps
+    benchmark: AsyncBenchmarkOps
     devbox: AsyncDevboxOps
     blueprint: AsyncBlueprintOps
+    network_policy: AsyncNetworkPolicyOps
     scenario: AsyncScenarioOps
     scorer: AsyncScorerOps
     snapshot: AsyncSnapshotOps
@@ -884,8 +1010,10 @@ class AsyncRunloopSDK:
         )
 
         self.agent = AsyncAgentOps(self.api)
+        self.benchmark = AsyncBenchmarkOps(self.api)
         self.devbox = AsyncDevboxOps(self.api)
         self.blueprint = AsyncBlueprintOps(self.api)
+        self.network_policy = AsyncNetworkPolicyOps(self.api)
         self.scenario = AsyncScenarioOps(self.api)
         self.scorer = AsyncScorerOps(self.api)
         self.snapshot = AsyncSnapshotOps(self.api)
