@@ -21,9 +21,13 @@ from ._types import (
     SDKObjectCreateParams,
     SDKScenarioListParams,
     SDKScorerCreateParams,
+    SDKBenchmarkListParams,
     SDKBlueprintListParams,
+    SDKBenchmarkCreateParams,
     SDKBlueprintCreateParams,
     SDKDiskSnapshotListParams,
+    SDKNetworkPolicyListParams,
+    SDKNetworkPolicyCreateParams,
     SDKDevboxCreateFromImageParams,
 )
 from .devbox import Devbox
@@ -33,8 +37,11 @@ from .._client import DEFAULT_MAX_RETRIES, Runloop
 from ._helpers import detect_content_type
 from .scenario import Scenario
 from .snapshot import Snapshot
+from .benchmark import Benchmark
 from .blueprint import Blueprint
+from .network_policy import NetworkPolicy
 from .storage_object import StorageObject
+from .scenario_builder import ScenarioBuilder
 from ..lib.context_loader import TarFilter, build_directory_tar
 from ..types.object_create_params import ContentType
 from ..types.shared_params.agent_source import Git, Npm, Pip, Object
@@ -593,7 +600,6 @@ class AgentOps:
         self,
         *,
         package_name: str,
-        npm_version: Optional[str] = None,
         registry_url: Optional[str] = None,
         agent_setup: Optional[list[str]] = None,
         **params: Unpack[SDKAgentCreateParams],
@@ -602,13 +608,11 @@ class AgentOps:
 
         Example:
             >>> agent = runloop.agent.create_from_npm(
-            ...     name="my-npm-agent", package_name="@runloop/example-agent", npm_version="^1.0.0"
+            ...     name="my-npm-agent", package_name="@runloop/example-agent", version="1.0.0"
             ... )
 
         :param package_name: NPM package name
         :type package_name: str
-        :param npm_version: NPM version constraint, defaults to None
-        :type npm_version: Optional[str], optional
         :param registry_url: NPM registry URL, defaults to None
         :type registry_url: Optional[str], optional
         :param agent_setup: Setup commands to run after installation, defaults to None
@@ -624,8 +628,6 @@ class AgentOps:
             )
 
         npm_config: Npm = {"package_name": package_name}
-        if npm_version is not None:
-            npm_config["npm_version"] = npm_version
         if registry_url is not None:
             npm_config["registry_url"] = registry_url
         if agent_setup is not None:
@@ -638,7 +640,6 @@ class AgentOps:
         self,
         *,
         package_name: str,
-        pip_version: Optional[str] = None,
         registry_url: Optional[str] = None,
         agent_setup: Optional[list[str]] = None,
         **params: Unpack[SDKAgentCreateParams],
@@ -647,13 +648,11 @@ class AgentOps:
 
         Example:
             >>> agent = runloop.agent.create_from_pip(
-            ...     name="my-pip-agent", package_name="runloop-example-agent", pip_version=">=1.0.0"
+            ...     name="my-pip-agent", package_name="runloop-example-agent", version="1.0.0"
             ... )
 
         :param package_name: Pip package name
         :type package_name: str
-        :param pip_version: Pip version constraint, defaults to None
-        :type pip_version: Optional[str], optional
         :param registry_url: Pip registry URL, defaults to None
         :type registry_url: Optional[str], optional
         :param agent_setup: Setup commands to run after installation, defaults to None
@@ -669,8 +668,6 @@ class AgentOps:
             )
 
         pip_config: Pip = {"package_name": package_name}
-        if pip_version is not None:
-            pip_config["pip_version"] = pip_version
         if registry_url is not None:
             pip_config["registry_url"] = registry_url
         if agent_setup is not None:
@@ -695,6 +692,7 @@ class AgentOps:
             ...     repository="https://github.com/user/agent-repo",
             ...     ref="main",
             ...     agent_setup=["npm install", "npm run build"],
+            ...     version="1.0.0",
             ... )
 
         :param repository: Git repository URL
@@ -736,7 +734,10 @@ class AgentOps:
             >>> obj = runloop.storage_object.upload_from_dir("./my-agent")
             >>> # Then create agent from the object
             >>> agent = runloop.agent.create_from_object(
-            ...     name="my-object-agent", object_id=obj.id, agent_setup=["chmod +x setup.sh", "./setup.sh"]
+            ...     name="my-object-agent",
+            ...     object_id=obj.id,
+            ...     agent_setup=["chmod +x setup.sh", "./setup.sh"],
+            ...     version="1.0.0",
             ... )
 
         :param object_id: Storage object ID
@@ -794,6 +795,16 @@ class ScenarioOps:
         >>> scenario = runloop.scenario.from_id("scn-xxx")
         >>> run = scenario.run()
         >>> scenarios = runloop.scenario.list()
+
+    Example using builder:
+        >>> builder = (
+        ...     runloop.scenario.builder("my-scenario")
+        ...     .from_blueprint(blueprint)
+        ...     .with_problem_statement("Fix the bug")
+        ...     .add_test_command_scorer("tests", test_command="pytest")
+        ... )
+        >>> params = builder.build()
+        >>> scenario = runloop.scenario.create(**params)  # equivalent to builder.push()
     """
 
     def __init__(self, client: Runloop) -> None:
@@ -804,6 +815,16 @@ class ScenarioOps:
         """
         self._client = client
 
+    def builder(self, name: str) -> ScenarioBuilder:
+        """Create a new scenario builder.
+
+        :param name: Name for the scenario
+        :type name: str
+        :return: A new ScenarioBuilder instance
+        :rtype: ScenarioBuilder
+        """
+        return ScenarioBuilder(name, self._client)
+
     def from_id(self, scenario_id: str) -> Scenario:
         """Get a Scenario instance for an existing scenario ID.
 
@@ -825,6 +846,109 @@ class ScenarioOps:
         return [Scenario(self._client, item.id) for item in page]
 
 
+class BenchmarkOps:
+    """Manage benchmarks. Access via ``runloop.benchmark``.
+
+    Example:
+        >>> runloop = RunloopSDK()
+        >>> benchmarks = runloop.benchmark.list()
+        >>> benchmark = runloop.benchmark.from_id("bmd_xxx")
+        >>> run = benchmark.start_run(run_name="evaluation-v1")
+    """
+
+    def __init__(self, client: Runloop) -> None:
+        """Initialize BenchmarkOps.
+
+        :param client: Runloop client instance
+        :type client: Runloop
+        """
+        self._client = client
+
+    def create(self, **params: Unpack[SDKBenchmarkCreateParams]) -> Benchmark:
+        """Create a new benchmark.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKBenchmarkCreateParams` for available parameters
+        :return: The newly created benchmark
+        :rtype: Benchmark
+        """
+        response = self._client.benchmarks.create(**params)
+        return Benchmark(self._client, response.id)
+
+    def from_id(self, benchmark_id: str) -> Benchmark:
+        """Get a Benchmark instance for an existing benchmark ID.
+
+        :param benchmark_id: ID of the benchmark
+        :type benchmark_id: str
+        :return: Benchmark instance for the given ID
+        :rtype: Benchmark
+        """
+        return Benchmark(self._client, benchmark_id)
+
+    def list(self, **params: Unpack[SDKBenchmarkListParams]) -> list[Benchmark]:
+        """List all benchmarks, optionally filtered by parameters.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKBenchmarkListParams` for available parameters
+        :return: List of benchmarks
+        :rtype: list[Benchmark]
+        """
+        page = self._client.benchmarks.list(**params)
+        return [Benchmark(self._client, item.id) for item in page.benchmarks]
+
+
+class NetworkPolicyOps:
+    """High-level manager for creating and managing network policies.
+
+    Accessed via ``runloop.network_policy`` from :class:`RunloopSDK`, provides methods
+    to create, retrieve, update, delete, and list network policies.
+
+    Example:
+        >>> runloop = RunloopSDK()
+        >>> policy = runloop.network_policy.create(
+        ...     name="my-policy",
+        ...     allowed_hostnames=["github.com", "*.npmjs.org"],
+        ... )
+        >>> policies = runloop.network_policy.list()
+    """
+
+    def __init__(self, client: Runloop) -> None:
+        """Initialize NetworkPolicyOps.
+
+        :param client: Runloop client instance
+        :type client: Runloop
+        """
+        self._client = client
+
+    def create(self, **params: Unpack[SDKNetworkPolicyCreateParams]) -> NetworkPolicy:
+        """Create a new network policy.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKNetworkPolicyCreateParams` for available parameters
+        :return: The newly created network policy
+        :rtype: NetworkPolicy
+        """
+        response = self._client.network_policies.create(**params)
+        return NetworkPolicy(self._client, response.id)
+
+    def from_id(self, network_policy_id: str) -> NetworkPolicy:
+        """Get a NetworkPolicy instance for an existing network policy ID.
+
+        :param network_policy_id: ID of the network policy
+        :type network_policy_id: str
+        :return: NetworkPolicy instance for the given ID
+        :rtype: NetworkPolicy
+        """
+        return NetworkPolicy(self._client, network_policy_id)
+
+    def list(self, **params: Unpack[SDKNetworkPolicyListParams]) -> list[NetworkPolicy]:
+        """List all network policies, optionally filtered by parameters.
+
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKNetworkPolicyListParams` for available parameters
+        :return: List of network policies
+        :rtype: list[NetworkPolicy]
+        """
+        page = self._client.network_policies.list(**params)
+        return [NetworkPolicy(self._client, item.id) for item in page]
+
+
 class RunloopSDK:
     """High-level synchronous entry point for the Runloop SDK.
 
@@ -836,6 +960,8 @@ class RunloopSDK:
     :vartype api: Runloop
     :ivar agent: High-level interface for agent management.
     :vartype agent: AgentOps
+    :ivar benchmark: High-level interface for benchmark management
+    :vartype benchmark: BenchmarkOps
     :ivar devbox: High-level interface for devbox management
     :vartype devbox: DevboxOps
     :ivar blueprint: High-level interface for blueprint management
@@ -848,6 +974,8 @@ class RunloopSDK:
     :vartype snapshot: SnapshotOps
     :ivar storage_object: High-level interface for storage object management
     :vartype storage_object: StorageObjectOps
+    :ivar network_policy: High-level interface for network policy management
+    :vartype network_policy: NetworkPolicyOps
 
     Example:
         >>> runloop = RunloopSDK()  # Uses RUNLOOP_API_KEY env var
@@ -859,8 +987,10 @@ class RunloopSDK:
 
     api: Runloop
     agent: AgentOps
+    benchmark: BenchmarkOps
     devbox: DevboxOps
     blueprint: BlueprintOps
+    network_policy: NetworkPolicyOps
     scenario: ScenarioOps
     scorer: ScorerOps
     snapshot: SnapshotOps
@@ -905,8 +1035,10 @@ class RunloopSDK:
         )
 
         self.agent = AgentOps(self.api)
+        self.benchmark = BenchmarkOps(self.api)
         self.devbox = DevboxOps(self.api)
         self.blueprint = BlueprintOps(self.api)
+        self.network_policy = NetworkPolicyOps(self.api)
         self.scenario = ScenarioOps(self.api)
         self.scorer = ScorerOps(self.api)
         self.snapshot = SnapshotOps(self.api)
