@@ -26,21 +26,21 @@ class TestAsyncDevbox:
 
     def test_init(self, mock_async_client: AsyncMock) -> None:
         """Test AsyncDevbox initialization."""
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
-        assert devbox.id == "dev_123"
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
+        assert devbox.id == "dbx_123"
 
     def test_repr(self, mock_async_client: AsyncMock) -> None:
         """Test AsyncDevbox string representation."""
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
-        assert repr(devbox) == "<AsyncDevbox id='dev_123'>"
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
+        assert repr(devbox) == "<AsyncDevbox id='dbx_123'>"
 
     @pytest.mark.asyncio
     async def test_context_manager_enter_exit(self, mock_async_client: AsyncMock, devbox_view: MockDevboxView) -> None:
         """Test context manager behavior with successful shutdown."""
         mock_async_client.devboxes.shutdown = AsyncMock(return_value=devbox_view)
 
-        async with AsyncDevbox(mock_async_client, "dev_123") as devbox:
-            assert devbox.id == "dev_123"
+        async with AsyncDevbox(mock_async_client, "dbx_123") as devbox:
+            assert devbox.id == "dbx_123"
 
         call_kwargs = mock_async_client.devboxes.shutdown.call_args[1]
         assert "timeout" not in call_kwargs
@@ -51,7 +51,7 @@ class TestAsyncDevbox:
         mock_async_client.devboxes.shutdown = AsyncMock(side_effect=RuntimeError("Shutdown failed"))
 
         with pytest.raises(ValueError, match="Test error"):
-            async with AsyncDevbox(mock_async_client, "dev_123"):
+            async with AsyncDevbox(mock_async_client, "dbx_123"):
                 raise ValueError("Test error")
 
         # Shutdown should be called even when body raises exception
@@ -62,7 +62,7 @@ class TestAsyncDevbox:
         """Test get_info method."""
         mock_async_client.devboxes.retrieve = AsyncMock(return_value=devbox_view)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.get_info(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -72,7 +72,7 @@ class TestAsyncDevbox:
 
         assert result == devbox_view
         mock_async_client.devboxes.retrieve.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -85,12 +85,12 @@ class TestAsyncDevbox:
         mock_async_client.devboxes.await_running = AsyncMock(return_value=devbox_view)
         polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.await_running(polling_config=polling_config)
 
         assert result == devbox_view
         mock_async_client.devboxes.await_running.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             polling_config=polling_config,
         )
 
@@ -100,12 +100,12 @@ class TestAsyncDevbox:
         mock_async_client.devboxes.await_suspended = AsyncMock(return_value=devbox_view)
         polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.await_suspended(polling_config=polling_config)
 
         assert result == devbox_view
         mock_async_client.devboxes.await_suspended.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             polling_config=polling_config,
         )
 
@@ -114,7 +114,7 @@ class TestAsyncDevbox:
         """Test shutdown method."""
         mock_async_client.devboxes.shutdown = AsyncMock(return_value=devbox_view)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.shutdown(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -125,7 +125,7 @@ class TestAsyncDevbox:
 
         assert result == devbox_view
         mock_async_client.devboxes.shutdown.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -138,7 +138,7 @@ class TestAsyncDevbox:
         """Test suspend method."""
         mock_async_client.devboxes.suspend = AsyncMock(return_value=devbox_view)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.suspend(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -149,7 +149,7 @@ class TestAsyncDevbox:
 
         assert result == devbox_view
         mock_async_client.devboxes.suspend.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -161,9 +161,12 @@ class TestAsyncDevbox:
     async def test_resume(self, mock_async_client: AsyncMock, devbox_view: MockDevboxView) -> None:
         """Test resume method."""
         mock_async_client.devboxes.resume = AsyncMock(return_value=devbox_view)
+        mock_async_client.devboxes.await_running = AsyncMock(return_value=devbox_view)
+        polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.resume(
+            polling_config=polling_config,
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -173,7 +176,35 @@ class TestAsyncDevbox:
 
         assert result == devbox_view
         mock_async_client.devboxes.resume.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
+            extra_headers={"X-Custom": "value"},
+            extra_query={"param": "value"},
+            extra_body={"key": "value"},
+            timeout=30.0,
+            idempotency_key="key-123",
+        )
+        mock_async_client.devboxes.await_running.assert_called_once_with(
+            "dbx_123",
+            polling_config=polling_config,
+        )
+
+    @pytest.mark.asyncio
+    async def test_resume_async(self, mock_async_client: AsyncMock, devbox_view: MockDevboxView) -> None:
+        """Test resume_async method."""
+        mock_async_client.devboxes.resume = AsyncMock(return_value=devbox_view)
+
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
+        result = await devbox.resume_async(
+            extra_headers={"X-Custom": "value"},
+            extra_query={"param": "value"},
+            extra_body={"key": "value"},
+            timeout=30.0,
+            idempotency_key="key-123",
+        )
+
+        assert result == devbox_view
+        mock_async_client.devboxes.resume.assert_called_once_with(
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -186,7 +217,7 @@ class TestAsyncDevbox:
         """Test keep_alive method."""
         mock_async_client.devboxes.keep_alive = AsyncMock(return_value=object())
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         result = await devbox.keep_alive(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -197,7 +228,7 @@ class TestAsyncDevbox:
 
         assert result is not None  # Verify return value is propagated
         mock_async_client.devboxes.keep_alive.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -208,13 +239,13 @@ class TestAsyncDevbox:
     @pytest.mark.asyncio
     async def test_snapshot_disk(self, mock_async_client: AsyncMock) -> None:
         """Test snapshot_disk waits for completion."""
-        snapshot_data = SimpleNamespace(id="snap_123")
+        snapshot_data = SimpleNamespace(id="snp_123")
         snapshot_status = SimpleNamespace(status="completed")
 
         mock_async_client.devboxes.snapshot_disk_async = AsyncMock(return_value=snapshot_data)
         mock_async_client.devboxes.disk_snapshots.await_completed = AsyncMock(return_value=snapshot_status)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         polling_config = PollingConfig(timeout_seconds=60.0)
         snapshot = await devbox.snapshot_disk(
             name="test-snapshot",
@@ -223,7 +254,7 @@ class TestAsyncDevbox:
             extra_headers={"X-Custom": "value"},
         )
 
-        assert snapshot.id == "snap_123"
+        assert snapshot.id == "snp_123"
         mock_async_client.devboxes.snapshot_disk_async.assert_called_once()
         call_kwargs = mock_async_client.devboxes.snapshot_disk_async.call_args[1]
         assert "commit_message" not in call_kwargs
@@ -240,17 +271,17 @@ class TestAsyncDevbox:
     @pytest.mark.asyncio
     async def test_snapshot_disk_async(self, mock_async_client: AsyncMock) -> None:
         """Test snapshot_disk_async returns immediately."""
-        snapshot_data = SimpleNamespace(id="snap_123")
+        snapshot_data = SimpleNamespace(id="snp_123")
         mock_async_client.devboxes.snapshot_disk_async = AsyncMock(return_value=snapshot_data)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         snapshot = await devbox.snapshot_disk_async(
             name="test-snapshot",
             metadata={"key": "value"},
             extra_headers={"X-Custom": "value"},
         )
 
-        assert snapshot.id == "snap_123"
+        assert snapshot.id == "snp_123"
         mock_async_client.devboxes.snapshot_disk_async.assert_called_once()
         call_kwargs = mock_async_client.devboxes.snapshot_disk_async.call_args[1]
         assert "commit_message" not in call_kwargs
@@ -265,7 +296,7 @@ class TestAsyncDevbox:
         """Test close method calls shutdown."""
         mock_async_client.devboxes.shutdown = AsyncMock(return_value=devbox_view)
 
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         await devbox.close()
 
         mock_async_client.devboxes.shutdown.assert_called_once()
@@ -274,21 +305,21 @@ class TestAsyncDevbox:
 
     def test_cmd_property(self, mock_async_client: AsyncMock) -> None:
         """Test cmd property returns AsyncCommandInterface."""
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         cmd = devbox.cmd
         assert isinstance(cmd, AsyncCommandInterface)
         assert cmd._devbox is devbox
 
     def test_file_property(self, mock_async_client: AsyncMock) -> None:
         """Test file property returns AsyncFileInterface."""
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         file_interface = devbox.file
         assert isinstance(file_interface, AsyncFileInterface)
         assert file_interface._devbox is devbox
 
     def test_net_property(self, mock_async_client: AsyncMock) -> None:
         """Test net property returns AsyncNetworkInterface."""
-        devbox = AsyncDevbox(mock_async_client, "dev_123")
+        devbox = AsyncDevbox(mock_async_client, "dbx_123")
         net = devbox.net
         assert isinstance(net, AsyncNetworkInterface)
         assert net._devbox is devbox
