@@ -29,20 +29,20 @@ class TestDevbox:
 
     def test_init(self, mock_client: Mock) -> None:
         """Test Devbox initialization."""
-        devbox = Devbox(mock_client, "dev_123")
-        assert devbox.id == "dev_123"
+        devbox = Devbox(mock_client, "dbx_123")
+        assert devbox.id == "dbx_123"
 
     def test_repr(self, mock_client: Mock) -> None:
         """Test Devbox string representation."""
-        devbox = Devbox(mock_client, "dev_123")
-        assert repr(devbox) == "<Devbox id='dev_123'>"
+        devbox = Devbox(mock_client, "dbx_123")
+        assert repr(devbox) == "<Devbox id='dbx_123'>"
 
     def test_context_manager_enter_exit(self, mock_client: Mock, devbox_view: MockDevboxView) -> None:
         """Test context manager behavior with successful shutdown."""
         mock_client.devboxes.shutdown.return_value = devbox_view
 
-        with Devbox(mock_client, "dev_123") as devbox:
-            assert devbox.id == "dev_123"
+        with Devbox(mock_client, "dbx_123") as devbox:
+            assert devbox.id == "dbx_123"
 
         call_kwargs = mock_client.devboxes.shutdown.call_args[1]
         assert "timeout" not in call_kwargs
@@ -52,7 +52,7 @@ class TestDevbox:
         mock_client.devboxes.shutdown.side_effect = RuntimeError("Shutdown failed")
 
         with pytest.raises(ValueError, match="Test error"):
-            with Devbox(mock_client, "dev_123"):
+            with Devbox(mock_client, "dbx_123"):
                 raise ValueError("Test error")
 
         # Shutdown should be called even when body raises exception
@@ -62,7 +62,7 @@ class TestDevbox:
         """Test get_info method."""
         mock_client.devboxes.retrieve.return_value = devbox_view
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.get_info(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -72,7 +72,7 @@ class TestDevbox:
 
         assert result == devbox_view
         mock_client.devboxes.retrieve.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -84,12 +84,12 @@ class TestDevbox:
         mock_client.devboxes.await_running.return_value = devbox_view
         polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.await_running(polling_config=polling_config)
 
         assert result == devbox_view
         mock_client.devboxes.await_running.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             polling_config=polling_config,
         )
 
@@ -98,12 +98,12 @@ class TestDevbox:
         mock_client.devboxes.await_suspended.return_value = devbox_view
         polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.await_suspended(polling_config=polling_config)
 
         assert result == devbox_view
         mock_client.devboxes.await_suspended.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             polling_config=polling_config,
         )
 
@@ -111,7 +111,7 @@ class TestDevbox:
         """Test shutdown method."""
         mock_client.devboxes.shutdown.return_value = devbox_view
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.shutdown(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -122,7 +122,7 @@ class TestDevbox:
 
         assert result == devbox_view
         mock_client.devboxes.shutdown.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -136,7 +136,7 @@ class TestDevbox:
         mock_client.devboxes.await_suspended.return_value = devbox_view
         polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.suspend(
             polling_config=polling_config,
             extra_headers={"X-Custom": "value"},
@@ -148,7 +148,7 @@ class TestDevbox:
 
         assert result == devbox_view
         mock_client.devboxes.suspend.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -156,7 +156,7 @@ class TestDevbox:
             idempotency_key="key-123",
         )
         mock_client.devboxes.await_suspended.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             polling_config=polling_config,
         )
 
@@ -166,7 +166,7 @@ class TestDevbox:
         mock_client.devboxes.await_running.return_value = devbox_view
         polling_config = PollingConfig(timeout_seconds=60.0)
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.resume(
             polling_config=polling_config,
             extra_headers={"X-Custom": "value"},
@@ -178,7 +178,7 @@ class TestDevbox:
 
         assert result == devbox_view
         mock_client.devboxes.resume.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -186,15 +186,41 @@ class TestDevbox:
             idempotency_key="key-123",
         )
         mock_client.devboxes.await_running.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             polling_config=polling_config,
         )
 
+    def test_resume_async(self, mock_client: Mock, devbox_view: MockDevboxView) -> None:
+        """Test resume_async method."""
+        mock_client.devboxes.resume.return_value = devbox_view
+        mock_client.devboxes.await_running = Mock()
+
+        devbox = Devbox(mock_client, "dbx_123")
+        result = devbox.resume_async(
+            extra_headers={"X-Custom": "value"},
+            extra_query={"param": "value"},
+            extra_body={"key": "value"},
+            timeout=30.0,
+            idempotency_key="key-123",
+        )
+
+        assert result == devbox_view
+        mock_client.devboxes.resume.assert_called_once_with(
+            "dbx_123",
+            extra_headers={"X-Custom": "value"},
+            extra_query={"param": "value"},
+            extra_body={"key": "value"},
+            timeout=30.0,
+            idempotency_key="key-123",
+        )
+        # Should not call await_running
+        mock_client.devboxes.await_running.assert_not_called()
+
     def test_keep_alive(self, mock_client: Mock) -> None:
         """Test keep_alive method."""
         mock_client.devboxes.keep_alive.return_value = object()
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         result = devbox.keep_alive(
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
@@ -205,7 +231,7 @@ class TestDevbox:
 
         assert result is not None  # Verify return value is propagated
         mock_client.devboxes.keep_alive.assert_called_once_with(
-            "dev_123",
+            "dbx_123",
             extra_headers={"X-Custom": "value"},
             extra_query={"param": "value"},
             extra_body={"key": "value"},
@@ -215,13 +241,13 @@ class TestDevbox:
 
     def test_snapshot_disk(self, mock_client: Mock) -> None:
         """Test snapshot_disk waits for completion."""
-        snapshot_data = SimpleNamespace(id="snap_123")
+        snapshot_data = SimpleNamespace(id="snp_123")
         snapshot_status = SimpleNamespace(status="completed")
 
         mock_client.devboxes.snapshot_disk_async.return_value = snapshot_data
         mock_client.devboxes.disk_snapshots.await_completed.return_value = snapshot_status
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         polling_config = PollingConfig(timeout_seconds=60.0)
         snapshot = devbox.snapshot_disk(
             name="test-snapshot",
@@ -230,7 +256,7 @@ class TestDevbox:
             extra_headers={"X-Custom": "value"},
         )
 
-        assert snapshot.id == "snap_123"
+        assert snapshot.id == "snp_123"
         call_kwargs = mock_client.devboxes.snapshot_disk_async.call_args[1]
         assert "commit_message" not in call_kwargs or call_kwargs["commit_message"] in (omit, None)
         assert call_kwargs["metadata"] == {"key": "value"}
@@ -244,17 +270,17 @@ class TestDevbox:
 
     def test_snapshot_disk_async(self, mock_client: Mock) -> None:
         """Test snapshot_disk_async returns immediately."""
-        snapshot_data = SimpleNamespace(id="snap_123")
+        snapshot_data = SimpleNamespace(id="snp_123")
         mock_client.devboxes.snapshot_disk_async.return_value = snapshot_data
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         snapshot = devbox.snapshot_disk_async(
             name="test-snapshot",
             metadata={"key": "value"},
             extra_headers={"X-Custom": "value"},
         )
 
-        assert snapshot.id == "snap_123"
+        assert snapshot.id == "snp_123"
         call_kwargs = mock_client.devboxes.snapshot_disk_async.call_args[1]
         assert "commit_message" not in call_kwargs or call_kwargs["commit_message"] in (omit, None)
         assert call_kwargs["metadata"] == {"key": "value"}
@@ -270,7 +296,7 @@ class TestDevbox:
         """Test close method calls shutdown."""
         mock_client.devboxes.shutdown.return_value = devbox_view
 
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         devbox.close()
 
         call_kwargs = mock_client.devboxes.shutdown.call_args[1]
@@ -278,21 +304,21 @@ class TestDevbox:
 
     def test_cmd_property(self, mock_client: Mock) -> None:
         """Test cmd property returns CommandInterface."""
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         cmd = devbox.cmd
         assert isinstance(cmd, CommandInterface)
         assert cmd._devbox is devbox
 
     def test_file_property(self, mock_client: Mock) -> None:
         """Test file property returns FileInterface."""
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         file_interface = devbox.file
         assert isinstance(file_interface, FileInterface)
         assert file_interface._devbox is devbox
 
     def test_net_property(self, mock_client: Mock) -> None:
         """Test net property returns NetworkInterface."""
-        devbox = Devbox(mock_client, "dev_123")
+        devbox = Devbox(mock_client, "dbx_123")
         net = devbox.net
         assert isinstance(net, NetworkInterface)
         assert net._devbox is devbox
