@@ -17,24 +17,30 @@ from tests.sdk.conftest import (
     MockScorerView,
     MockScenarioView,
     MockSnapshotView,
+    MockBenchmarkView,
     MockBlueprintView,
+    MockNetworkPolicyView,
     create_mock_httpx_response,
 )
 from runloop_api_client.sdk import (
     AsyncAgent,
     AsyncDevbox,
     AsyncScorer,
-    AsyncSnapshot,
-    AsyncBlueprint,
-    AsyncStorageObject,
-)
-from runloop_api_client.sdk.async_ import (
     AsyncAgentOps,
+    AsyncScenario,
+    AsyncSnapshot,
+    AsyncBenchmark,
+    AsyncBlueprint,
     AsyncDevboxOps,
     AsyncScorerOps,
     AsyncRunloopSDK,
+    AsyncScenarioOps,
     AsyncSnapshotOps,
+    AsyncBenchmarkOps,
     AsyncBlueprintOps,
+    AsyncNetworkPolicy,
+    AsyncStorageObject,
+    AsyncNetworkPolicyOps,
     AsyncStorageObjectOps,
 )
 from runloop_api_client.lib.polling import PollingConfig
@@ -56,7 +62,7 @@ class TestAsyncDevboxOps:
         )
 
         assert isinstance(devbox, AsyncDevbox)
-        assert devbox.id == "dev_123"
+        assert devbox.id == "dbx_123"
         mock_async_client.devboxes.create_and_await_running.assert_awaited_once()
 
     @pytest.mark.asyncio
@@ -66,13 +72,13 @@ class TestAsyncDevboxOps:
 
         ops = AsyncDevboxOps(mock_async_client)
         devbox = await ops.create_from_blueprint_id(
-            "bp_123",
+            "bpt_123",
             name="test-devbox",
         )
 
         assert isinstance(devbox, AsyncDevbox)
         call_kwargs = mock_async_client.devboxes.create_and_await_running.call_args[1]
-        assert call_kwargs["blueprint_id"] == "bp_123"
+        assert call_kwargs["blueprint_id"] == "bpt_123"
 
     @pytest.mark.asyncio
     async def test_create_from_blueprint_name(self, mock_async_client: AsyncMock, devbox_view: MockDevboxView) -> None:
@@ -96,21 +102,21 @@ class TestAsyncDevboxOps:
 
         ops = AsyncDevboxOps(mock_async_client)
         devbox = await ops.create_from_snapshot(
-            "snap_123",
+            "snp_123",
             name="test-devbox",
         )
 
         assert isinstance(devbox, AsyncDevbox)
         call_kwargs = mock_async_client.devboxes.create_and_await_running.call_args[1]
-        assert call_kwargs["snapshot_id"] == "snap_123"
+        assert call_kwargs["snapshot_id"] == "snp_123"
 
     def test_from_id(self, mock_async_client: AsyncMock) -> None:
         """Test from_id method."""
         ops = AsyncDevboxOps(mock_async_client)
-        devbox = ops.from_id("dev_123")
+        devbox = ops.from_id("dbx_123")
 
         assert isinstance(devbox, AsyncDevbox)
-        assert devbox.id == "dev_123"
+        assert devbox.id == "dbx_123"
         # Verify from_id does not wait for running status
         if hasattr(mock_async_client.devboxes, "await_running"):
             assert not mock_async_client.devboxes.await_running.called
@@ -142,7 +148,7 @@ class TestAsyncDevboxOps:
 
         assert len(devboxes) == 1
         assert isinstance(devboxes[0], AsyncDevbox)
-        assert devboxes[0].id == "dev_123"
+        assert devboxes[0].id == "dbx_123"
         mock_async_client.devboxes.list.assert_awaited_once()
 
     @pytest.mark.asyncio
@@ -174,7 +180,7 @@ class TestAsyncSnapshotOps:
         mock_async_client.devboxes.disk_snapshots.list = AsyncMock(return_value=page)
 
         ops = AsyncSnapshotOps(mock_async_client)
-        snapshots = await ops.list(devbox_id="dev_123", limit=10)
+        snapshots = await ops.list(devbox_id="dbx_123", limit=10)
 
         assert len(snapshots) == 0
         mock_async_client.devboxes.disk_snapshots.list.assert_awaited_once()
@@ -187,14 +193,14 @@ class TestAsyncSnapshotOps:
 
         ops = AsyncSnapshotOps(mock_async_client)
         snapshots = await ops.list(
-            devbox_id="dev_123",
+            devbox_id="dbx_123",
             limit=10,
             starting_after="snap_000",
         )
 
         assert len(snapshots) == 1
         assert isinstance(snapshots[0], AsyncSnapshot)
-        assert snapshots[0].id == "snap_123"
+        assert snapshots[0].id == "snp_123"
         mock_async_client.devboxes.disk_snapshots.list.assert_awaited_once()
 
     @pytest.mark.asyncio
@@ -206,7 +212,7 @@ class TestAsyncSnapshotOps:
         mock_async_client.devboxes.disk_snapshots.list = AsyncMock(return_value=page)
 
         ops = AsyncSnapshotOps(mock_async_client)
-        snapshots = await ops.list(devbox_id="dev_123", limit=10)
+        snapshots = await ops.list(devbox_id="dbx_123", limit=10)
 
         assert len(snapshots) == 2
         assert isinstance(snapshots[0], AsyncSnapshot)
@@ -218,10 +224,10 @@ class TestAsyncSnapshotOps:
     def test_from_id(self, mock_async_client: AsyncMock) -> None:
         """Test from_id method."""
         ops = AsyncSnapshotOps(mock_async_client)
-        snapshot = ops.from_id("snap_123")
+        snapshot = ops.from_id("snp_123")
 
         assert isinstance(snapshot, AsyncSnapshot)
-        assert snapshot.id == "snap_123"
+        assert snapshot.id == "snp_123"
 
 
 class TestAsyncBlueprintOps:
@@ -239,16 +245,16 @@ class TestAsyncBlueprintOps:
         )
 
         assert isinstance(blueprint, AsyncBlueprint)
-        assert blueprint.id == "bp_123"
+        assert blueprint.id == "bpt_123"
         mock_async_client.blueprints.create_and_await_build_complete.assert_awaited_once()
 
     def test_from_id(self, mock_async_client: AsyncMock) -> None:
         """Test from_id method."""
         ops = AsyncBlueprintOps(mock_async_client)
-        blueprint = ops.from_id("bp_123")
+        blueprint = ops.from_id("bpt_123")
 
         assert isinstance(blueprint, AsyncBlueprint)
-        assert blueprint.id == "bp_123"
+        assert blueprint.id == "bpt_123"
 
     @pytest.mark.asyncio
     async def test_list_empty(self, mock_async_client: AsyncMock) -> None:
@@ -277,7 +283,7 @@ class TestAsyncBlueprintOps:
 
         assert len(blueprints) == 1
         assert isinstance(blueprints[0], AsyncBlueprint)
-        assert blueprints[0].id == "bp_123"
+        assert blueprints[0].id == "bpt_123"
         mock_async_client.blueprints.list.assert_awaited_once()
 
     @pytest.mark.asyncio
@@ -712,16 +718,16 @@ class TestAsyncScorerOps:
         )
 
         assert isinstance(scorer, AsyncScorer)
-        assert scorer.id == "scorer_123"
+        assert scorer.id == "sco_123"
         mock_async_client.scenarios.scorers.create.assert_awaited_once()
 
     def test_from_id(self, mock_async_client: AsyncMock) -> None:
         """Test from_id method."""
         ops = AsyncScorerOps(mock_async_client)
-        scorer = ops.from_id("scorer_123")
+        scorer = ops.from_id("sco_123")
 
         assert isinstance(scorer, AsyncScorer)
-        assert scorer.id == "scorer_123"
+        assert scorer.id == "sco_123"
 
     @pytest.mark.asyncio
     async def test_list_empty(self, mock_async_client: AsyncMock) -> None:
@@ -756,7 +762,7 @@ class TestAsyncScorerOps:
 
         assert len(scorers) == 1
         assert isinstance(scorers[0], AsyncScorer)
-        assert scorers[0].id == "scorer_123"
+        assert scorers[0].id == "sco_123"
         mock_async_client.scenarios.scorers.list.assert_awaited_once()
 
     @pytest.mark.asyncio
@@ -793,19 +799,20 @@ class TestAsyncAgentClient:
         client = AsyncAgentOps(mock_async_client)
         agent = await client.create(
             name="test-agent",
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_called_once()
 
     def test_from_id(self, mock_async_client: AsyncMock) -> None:
         """Test from_id method."""
         client = AsyncAgentOps(mock_async_client)
-        agent = client.from_id("agent_123")
+        agent = client.from_id("agt_123")
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
 
     @pytest.mark.asyncio
     async def test_list(self, mock_async_client: AsyncMock) -> None:
@@ -901,10 +908,11 @@ class TestAsyncAgentClient:
         agent = await client.create_from_npm(
             name="test-agent",
             package_name="@runloop/example-agent",
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "npm",
@@ -913,6 +921,7 @@ class TestAsyncAgentClient:
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
     @pytest.mark.asyncio
@@ -926,25 +935,25 @@ class TestAsyncAgentClient:
         agent = await client.create_from_npm(
             name="test-agent",
             package_name="@runloop/example-agent",
-            npm_version="1.2.3",
             registry_url="https://registry.example.com",
             agent_setup=["npm install", "npm run setup"],
+            version="1.2.3",
             extra_headers={"X-Custom": "header"},
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "npm",
                 "npm": {
                     "package_name": "@runloop/example-agent",
-                    "npm_version": "1.2.3",
                     "registry_url": "https://registry.example.com",
                     "agent_setup": ["npm install", "npm run setup"],
                 },
             },
             name="test-agent",
+            version="1.2.3",
             extra_headers={"X-Custom": "header"},
         )
 
@@ -957,6 +966,7 @@ class TestAsyncAgentClient:
             await client.create_from_npm(
                 name="test-agent",
                 package_name="@runloop/example-agent",
+                version="1.2.3",
                 source={"type": "git", "git": {"repository": "https://github.com/example/repo"}},
             )
 
@@ -969,10 +979,11 @@ class TestAsyncAgentClient:
         agent = await client.create_from_pip(
             name="test-agent",
             package_name="runloop-example-agent",
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "pip",
@@ -981,6 +992,7 @@ class TestAsyncAgentClient:
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
     @pytest.mark.asyncio
@@ -994,24 +1006,24 @@ class TestAsyncAgentClient:
         agent = await client.create_from_pip(
             name="test-agent",
             package_name="runloop-example-agent",
-            pip_version="1.2.3",
             registry_url="https://pypi.example.com",
             agent_setup=["pip install extra-deps"],
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "pip",
                 "pip": {
                     "package_name": "runloop-example-agent",
-                    "pip_version": "1.2.3",
                     "registry_url": "https://pypi.example.com",
                     "agent_setup": ["pip install extra-deps"],
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
     @pytest.mark.asyncio
@@ -1023,10 +1035,11 @@ class TestAsyncAgentClient:
         agent = await client.create_from_git(
             name="test-agent",
             repository="https://github.com/example/agent-repo",
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "git",
@@ -1035,6 +1048,7 @@ class TestAsyncAgentClient:
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
     @pytest.mark.asyncio
@@ -1050,10 +1064,11 @@ class TestAsyncAgentClient:
             repository="https://github.com/example/agent-repo",
             ref="develop",
             agent_setup=["npm install", "npm run build"],
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "git",
@@ -1064,6 +1079,7 @@ class TestAsyncAgentClient:
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
     @pytest.mark.asyncio
@@ -1075,10 +1091,11 @@ class TestAsyncAgentClient:
         agent = await client.create_from_object(
             name="test-agent",
             object_id="obj_123",
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "object",
@@ -1087,6 +1104,7 @@ class TestAsyncAgentClient:
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
     @pytest.mark.asyncio
@@ -1101,10 +1119,11 @@ class TestAsyncAgentClient:
             name="test-agent",
             object_id="obj_123",
             agent_setup=["chmod +x setup.sh", "./setup.sh"],
+            version="1.2.3",
         )
 
         assert isinstance(agent, AsyncAgent)
-        assert agent.id == "agent_123"
+        assert agent.id == "agt_123"
         mock_async_client.agents.create.assert_awaited_once_with(
             source={
                 "type": "object",
@@ -1114,6 +1133,7 @@ class TestAsyncAgentClient:
                 },
             },
             name="test-agent",
+            version="1.2.3",
         )
 
 
@@ -1122,8 +1142,6 @@ class TestAsyncScenarioOps:
 
     def test_from_id(self, mock_async_client: AsyncMock) -> None:
         """Test from_id method."""
-        from runloop_api_client.sdk import AsyncScenario
-        from runloop_api_client.sdk.async_ import AsyncScenarioOps
 
         ops = AsyncScenarioOps(mock_async_client)
         scenario = ops.from_id("scn_123")
@@ -1134,7 +1152,6 @@ class TestAsyncScenarioOps:
     @pytest.mark.asyncio
     async def test_list_empty(self, mock_async_client: AsyncMock) -> None:
         """Test list method with empty results."""
-        from runloop_api_client.sdk.async_ import AsyncScenarioOps
 
         async def async_iter():
             return
@@ -1151,8 +1168,6 @@ class TestAsyncScenarioOps:
     @pytest.mark.asyncio
     async def test_list_single(self, mock_async_client: AsyncMock, scenario_view: MockScenarioView) -> None:
         """Test list method with single result."""
-        from runloop_api_client.sdk import AsyncScenario
-        from runloop_api_client.sdk.async_ import AsyncScenarioOps
 
         async def async_iter():
             yield scenario_view
@@ -1170,8 +1185,6 @@ class TestAsyncScenarioOps:
     @pytest.mark.asyncio
     async def test_list_multiple(self, mock_async_client: AsyncMock) -> None:
         """Test list method with multiple results."""
-        from runloop_api_client.sdk import AsyncScenario
-        from runloop_api_client.sdk.async_ import AsyncScenarioOps
 
         scenario_view1 = MockScenarioView(id="scn_001", name="scenario-1")
         scenario_view2 = MockScenarioView(id="scn_002", name="scenario-2")
@@ -1193,38 +1206,178 @@ class TestAsyncScenarioOps:
         mock_async_client.scenarios.list.assert_awaited_once()
 
 
+class TestAsyncBenchmarkOps:
+    """Tests for AsyncBenchmarkOps class."""
+
+    @pytest.mark.asyncio
+    async def test_create(self, mock_async_client: AsyncMock, benchmark_view: MockBenchmarkView) -> None:
+        """Test create method."""
+        mock_async_client.benchmarks.create = AsyncMock(return_value=benchmark_view)
+
+        ops = AsyncBenchmarkOps(mock_async_client)
+        benchmark = await ops.create(name="test-benchmark", scenario_ids=["scn_001", "scn_002"])
+
+        assert isinstance(benchmark, AsyncBenchmark)
+        assert benchmark.id == "bmd_123"
+        mock_async_client.benchmarks.create.assert_awaited_once_with(
+            name="test-benchmark", scenario_ids=["scn_001", "scn_002"]
+        )
+
+    def test_from_id(self, mock_async_client: AsyncMock) -> None:
+        """Test from_id method."""
+        ops = AsyncBenchmarkOps(mock_async_client)
+        benchmark = ops.from_id("bmd_123")
+
+        assert isinstance(benchmark, AsyncBenchmark)
+        assert benchmark.id == "bmd_123"
+
+    @pytest.mark.asyncio
+    async def test_list_multiple(self, mock_async_client: AsyncMock) -> None:
+        """Test list method with multiple results."""
+        benchmark_view1 = MockBenchmarkView(id="bmd_001", name="benchmark-1")
+        benchmark_view2 = MockBenchmarkView(id="bmd_002", name="benchmark-2")
+        page = SimpleNamespace(benchmarks=[benchmark_view1, benchmark_view2])
+        mock_async_client.benchmarks.list = AsyncMock(return_value=page)
+
+        ops = AsyncBenchmarkOps(mock_async_client)
+        benchmarks = await ops.list(limit=10)
+
+        assert len(benchmarks) == 2
+        assert isinstance(benchmarks[0], AsyncBenchmark)
+        assert isinstance(benchmarks[1], AsyncBenchmark)
+        assert benchmarks[0].id == "bmd_001"
+        assert benchmarks[1].id == "bmd_002"
+        mock_async_client.benchmarks.list.assert_awaited_once_with(limit=10)
+
+    @pytest.mark.asyncio
+    async def test_list_with_name_filter(self, mock_async_client: AsyncMock, benchmark_view: MockBenchmarkView) -> None:
+        """Test list method with name filter."""
+        page = SimpleNamespace(benchmarks=[benchmark_view])
+        mock_async_client.benchmarks.list = AsyncMock(return_value=page)
+
+        ops = AsyncBenchmarkOps(mock_async_client)
+        benchmarks = await ops.list(name="test-benchmark", limit=10)
+
+        assert len(benchmarks) == 1
+        mock_async_client.benchmarks.list.assert_awaited_once_with(name="test-benchmark", limit=10)
+
+
+class TestAsyncNetworkPolicyOps:
+    """Tests for AsyncNetworkPolicyOps class."""
+
+    @pytest.mark.asyncio
+    async def test_create(self, mock_async_client: AsyncMock, network_policy_view: MockNetworkPolicyView) -> None:
+        """Test create method."""
+        mock_async_client.network_policies.create = AsyncMock(return_value=network_policy_view)
+
+        ops = AsyncNetworkPolicyOps(mock_async_client)
+        network_policy = await ops.create(
+            name="test-network-policy",
+            allowed_hostnames=["github.com", "*.npmjs.org"],
+        )
+
+        assert isinstance(network_policy, AsyncNetworkPolicy)
+        assert network_policy.id == "np_123"
+        mock_async_client.network_policies.create.assert_awaited_once()
+
+    def test_from_id(self, mock_async_client: AsyncMock) -> None:
+        """Test from_id method."""
+        ops = AsyncNetworkPolicyOps(mock_async_client)
+        network_policy = ops.from_id("np_123")
+
+        assert isinstance(network_policy, AsyncNetworkPolicy)
+        assert network_policy.id == "np_123"
+
+    @pytest.mark.asyncio
+    async def test_list_empty(self, mock_async_client: AsyncMock) -> None:
+        """Test list method with empty results."""
+
+        async def async_iter():
+            return
+            yield  # Make this a generator
+
+        mock_async_client.network_policies.list.return_value = async_iter()
+
+        ops = AsyncNetworkPolicyOps(mock_async_client)
+        network_policies = await ops.list(limit=10)
+
+        assert len(network_policies) == 0
+
+    @pytest.mark.asyncio
+    async def test_list_single(self, mock_async_client: AsyncMock, network_policy_view: MockNetworkPolicyView) -> None:
+        """Test list method with single result."""
+
+        async def async_iter():
+            yield network_policy_view
+
+        mock_async_client.network_policies.list.return_value = async_iter()
+
+        ops = AsyncNetworkPolicyOps(mock_async_client)
+        network_policies = await ops.list(
+            limit=10,
+            starting_after="np_000",
+        )
+
+        assert len(network_policies) == 1
+        assert isinstance(network_policies[0], AsyncNetworkPolicy)
+        assert network_policies[0].id == "np_123"
+
+    @pytest.mark.asyncio
+    async def test_list_multiple(self, mock_async_client: AsyncMock) -> None:
+        """Test list method with multiple results."""
+        network_policy_view1 = MockNetworkPolicyView(id="np_001", name="policy-1")
+        network_policy_view2 = MockNetworkPolicyView(id="np_002", name="policy-2")
+
+        async def async_iter():
+            yield network_policy_view1
+            yield network_policy_view2
+
+        mock_async_client.network_policies.list.return_value = async_iter()
+
+        ops = AsyncNetworkPolicyOps(mock_async_client)
+        network_policies = await ops.list(limit=10)
+
+        assert len(network_policies) == 2
+        assert isinstance(network_policies[0], AsyncNetworkPolicy)
+        assert isinstance(network_policies[1], AsyncNetworkPolicy)
+        assert network_policies[0].id == "np_001"
+        assert network_policies[1].id == "np_002"
+
+
 class TestAsyncRunloopSDK:
     """Tests for AsyncRunloopSDK class."""
 
     def test_init(self) -> None:
         """Test AsyncRunloopSDK initialization."""
-        sdk = AsyncRunloopSDK(bearer_token="test-token")
-        assert sdk.api is not None
-        assert isinstance(sdk.agent, AsyncAgentOps)
-        assert isinstance(sdk.devbox, AsyncDevboxOps)
-        assert isinstance(sdk.scorer, AsyncScorerOps)
-        assert isinstance(sdk.snapshot, AsyncSnapshotOps)
-        assert isinstance(sdk.blueprint, AsyncBlueprintOps)
-        assert isinstance(sdk.storage_object, AsyncStorageObjectOps)
+        runloop = AsyncRunloopSDK(bearer_token="test-token")
+        assert runloop.api is not None
+        assert isinstance(runloop.agent, AsyncAgentOps)
+        assert isinstance(runloop.benchmark, AsyncBenchmarkOps)
+        assert isinstance(runloop.devbox, AsyncDevboxOps)
+        assert isinstance(runloop.network_policy, AsyncNetworkPolicyOps)
+        assert isinstance(runloop.scorer, AsyncScorerOps)
+        assert isinstance(runloop.snapshot, AsyncSnapshotOps)
+        assert isinstance(runloop.blueprint, AsyncBlueprintOps)
+        assert isinstance(runloop.storage_object, AsyncStorageObjectOps)
 
     @pytest.mark.asyncio
     async def test_aclose(self) -> None:
         """Test aclose method."""
-        sdk = AsyncRunloopSDK(bearer_token="test-token")
+        runloop = AsyncRunloopSDK(bearer_token="test-token")
         # Verify aclose doesn't raise
-        await sdk.aclose()
+        await runloop.aclose()
 
     @pytest.mark.asyncio
     async def test_context_manager(self) -> None:
         """Test context manager behavior."""
-        async with AsyncRunloopSDK(bearer_token="test-token") as sdk:
-            assert sdk.api is not None
+        async with AsyncRunloopSDK(bearer_token="test-token") as runloop:
+            assert runloop.api is not None
         # Verify context manager properly closes (implementation detail of context manager protocol)
 
     def test_api_property(self) -> None:
         """Test api property access."""
-        sdk = AsyncRunloopSDK(bearer_token="test-token")
-        assert sdk.api is not None
-        assert hasattr(sdk.api, "devboxes")
-        assert hasattr(sdk.api, "blueprints")
-        assert hasattr(sdk.api, "objects")
+        runloop = AsyncRunloopSDK(bearer_token="test-token")
+        assert runloop.api is not None
+        assert hasattr(runloop.api, "devboxes")
+        assert hasattr(runloop.api, "blueprints")
+        assert hasattr(runloop.api, "objects")
