@@ -346,12 +346,10 @@ class TestAsyncDevboxStateManagement:
             info = await devbox.get_info()
             assert info.status == "suspended"
 
-            # Resume the devbox
-            resumed_info = await devbox.resume()
-            if resumed_info.status != "running":
-                resumed_info = await devbox.await_running(
-                    polling_config=PollingConfig(timeout_seconds=120.0, interval_seconds=5.0)
-                )
+            # Resume the devbox - resume() automatically waits for running state
+            resumed_info = await devbox.resume(
+                polling_config=PollingConfig(timeout_seconds=120.0, interval_seconds=5.0)
+            )
             assert resumed_info.status == "running"
 
             # Verify running state
@@ -360,6 +358,45 @@ class TestAsyncDevboxStateManagement:
         finally:
             await devbox.shutdown()
 
+    @pytest.mark.timeout(TWO_MINUTE_TIMEOUT)
+    async def test_resume_async(self, async_sdk_client: AsyncRunloopSDK) -> None:
+        """Test resuming a devbox asynchronously without waiting."""
+        devbox = await async_sdk_client.devbox.create(
+            name=unique_name("sdk-async-devbox-resume-async"),
+            launch_parameters={"resource_size_request": "SMALL", "keep_alive_time_seconds": 60 * 5},
+        )
+        # wait for devbox to be running
+        await devbox.await_running(polling_config=PollingConfig(timeout_seconds=120.0, interval_seconds=5.0))
+
+        try:
+            # Suspend the devbox
+            suspended_info = await devbox.suspend()
+            if suspended_info.status != "suspended":
+                suspended_info = await devbox.await_suspended(
+                    polling_config=PollingConfig(timeout_seconds=120.0, interval_seconds=5.0)
+                )
+            assert suspended_info.status == "suspended"
+
+            # Verify suspended state
+            info = await devbox.get_info()
+            assert info.status == "suspended"
+
+            # Resume the devbox asynchronously - doesn't wait automatically
+            resume_response = await devbox.resume_async()
+            assert resume_response is not None
+
+            # Status might still be suspended or transitioning
+            info_after_resume = await devbox.get_info()
+            assert info_after_resume.status in ["suspended", "running", "starting", "provisioning"]
+
+            # Now wait for running state explicitly
+            running_info = await devbox.await_running(
+                polling_config=PollingConfig(timeout_seconds=120.0, interval_seconds=5.0)
+            )
+            assert running_info.status == "running"
+        finally:
+            await devbox.shutdown()
+
     @pytest.mark.timeout(TWO_MINUTE_TIMEOUT)
     async def test_await_running(self, async_sdk_client: AsyncRunloopSDK) -> None:
         """Test await_running method."""
@@ -431,7 +468,7 @@ class TestAsyncDevboxCreationMethods:
         # First create a blueprint
         blueprint = await async_sdk_client.blueprint.create(
             name=unique_name("sdk-async-blueprint-for-devbox"),
-            dockerfile="FROM ubuntu:20.04\nRUN apt-get update && apt-get install -y curl",
+            dockerfile="FROM ubuntu:22.04\nRUN apt-get update && apt-get install -y curl",
         )
 
         try:
@@ -459,7 +496,7 @@ class TestAsyncDevboxCreationMethods:
         # Create blueprint
         blueprint = await async_sdk_client.blueprint.create(
             name=blueprint_name,
-            dockerfile="FROM ubuntu:20.04\nRUN apt-get update && apt-get install -y wget",
+            dockerfile="FROM ubuntu:22.04\nRUN apt-get update && apt-get install -y wget",
         )
 
         try:
